unsync: Removes synchronization.

View source: R/leafletsync.R

unsyncR Documentation

Removes synchronization.

Description

Removes the synchronization of multiple maps from a specific map.

Usage

unsync(map, id = NULL, unsyncids = NULL)

Arguments

map

the map

id

The map id from which to unsynchronize the maps in unsyncids

unsyncids

Unsynchronize the maps with the following IDs

Value

A map

See Also

Other leafletsync Functions: addLeafletsync(), addLeafletsyncDependency(), isSynced(), leafletsyncOptions()


leaflet.extras2 documentation built on Sept. 10, 2026, 1:11 a.m.